==> kubernetes-model-core-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/ScaleIOPersistentVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ScaleIOPersistentVolumeSourceFluent<A extends ScaleIOPersistentVolumeSourceFluent<A>> extends Fluent<A>{
  public String getFsType();
  public A withFsType(String fsType);
  public Boolean hasFsType();
  public String getGateway();
  public A withGateway(String gateway);
  public Boolean hasGateway();
  public String getProtectionDomain();
  public A withProtectionDomain(String protectionDomain);
  public Boolean hasProtectionDomain();
  public Boolean getReadOnly();
  public A withReadOnly(Boolean readOnly);
  public Boolean hasReadOnly();
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretReference getSecretRef();
  public SecretReference buildSecretRef();
  public A withSecretRef(SecretReference secretRef);
  public Boolean hasSecretRef();
  public A withNewSecretRef(String name,String namespace);
  public ScaleIOPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
  public ScaleIOPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(SecretReference item);
  public ScaleIOPersistentVolumeSourceFluent.SecretRefNested<A> editSecretRef();
  public ScaleIOPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
  public ScaleIOPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(SecretReference item);
  public Boolean getSslEnabled();
  public A withSslEnabled(Boolean sslEnabled);
  public Boolean hasSslEnabled();
  public String getStorageMode();
  public A withStorageMode(String storageMode);
  public Boolean hasStorageMode();
  public String getStoragePool();
  public A withStoragePool(String storagePool);
  public Boolean hasStoragePool();
  public String getSystem();
  public A withSystem(String system);
  public Boolean hasSystem();
  public String getVolumeName();
  public A withVolumeName(String volumeName);
  public Boolean hasVolumeName();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withReadOnly();
  public A withSslEnabled();
  public interface SecretRefNested<N> extends Nested<N>,SecretReferenceFluent<ScaleIOPersistentVolumeSourceFluent.SecretRefNested<N>>{
    public N and();
    public N endSecretRef();
    
  }
  
}

==> kubernetes-model-core-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/ScaleIOPersistentVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ScaleIOPersistentVolumeSourceFluent<A extends ScaleIOPersistentVolumeSourceFluent<A>> extends Fluent<A>{
  public String getFsType();
  public A withFsType(String fsType);
  public Boolean hasFsType();
  public String getGateway();
  public A withGateway(String gateway);
  public Boolean hasGateway();
  public String getProtectionDomain();
  public A withProtectionDomain(String protectionDomain);
  public Boolean hasProtectionDomain();
  public Boolean getReadOnly();
  public A withReadOnly(Boolean readOnly);
  public Boolean hasReadOnly();
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretReference getSecretRef();
  public SecretReference buildSecretRef();
  public A withSecretRef(SecretReference secretRef);
  public Boolean hasSecretRef();
  public A withNewSecretRef(String name,String namespace);
  public ScaleIOPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
  public ScaleIOPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(SecretReference item);
  public ScaleIOPersistentVolumeSourceFluent.SecretRefNested<A> editSecretRef();
  public ScaleIOPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
  public ScaleIOPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(SecretReference item);
  public Boolean getSslEnabled();
  public A withSslEnabled(Boolean sslEnabled);
  public Boolean hasSslEnabled();
  public String getStorageMode();
  public A withStorageMode(String storageMode);
  public Boolean hasStorageMode();
  public String getStoragePool();
  public A withStoragePool(String storagePool);
  public Boolean hasStoragePool();
  public String getSystem();
  public A withSystem(String system);
  public Boolean hasSystem();
  public String getVolumeName();
  public A withVolumeName(String volumeName);
  public Boolean hasVolumeName();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withReadOnly();
  public A withSslEnabled();
  public interface SecretRefNested<N> extends Nested<N>,SecretReferenceFluent<ScaleIOPersistentVolumeSourceFluent.SecretRefNested<N>>{
    public N and();
    public N endSecretRef();
    
  }
  
}
